@@ -416,6 +416,12 @@ class RabbitMQClient:
                 self._start_keepalive()
 
                 self._update_activity_timestamp()
+
+                # 首次启动时延迟1秒（避免初始化未完成就接收消息）
+                if not force_reconnect:
+                    logger.info("客户端初始化成功，延迟1秒接收消息（解决启动时序问题）")
+                    await asyncio.sleep(1)
+
                 logger.info(f"RabbitMQ客户端初始化成功 (队列: {self.actual_queue_name})")
                 return
 
@@ -706,13 +712,26 @@ class RabbitMQClient:
         if await self._is_closed():
             raise Exception("客户端已关闭，无法启动消费")
 
-        # 检查连接状态
+        # 检查连接状态（确保通道完全就绪）
         if not await self.is_connected:
             await self.connect()
 
+        # 确保通道未关闭（解决启动时通道初始化滞后问题）
+        channel, _, _ = await self._get_connection_resources()
+        max_wait_attempts = 5
+        wait_interval = 0.5
+        for attempt in range(max_wait_attempts):
+            if channel and not channel.is_closed:
+                break
+            logger.debug(f"等待通道就绪（第{attempt+1}/{max_wait_attempts}次）")
+            await asyncio.sleep(wait_interval)
+            channel, _, _ = await self._get_connection_resources()
+        if not channel or channel.is_closed:
+            raise Exception("通道初始化失败，无法启动消费")
+
         # 获取消费状态和资源
         _, handler, consumer_tag = await self._get_consume_state()
-        channel, exchange, queue = await self._get_connection_resources()
+        _, exchange, queue = await self._get_connection_resources()
 
         # 检查是否已在消费（通过 consumer_tag 是否存在判断）
         if consumer_tag:
