@@ -191,6 +191,13 @@ class RabbitMQService:
 
         # 使用declare_queue控制是否声明队列（发送器不声明，监听器声明）
         await client.connect(declare_queue=not is_sender)
+
+        # 监听器客户端连接后延迟1秒，确保消费状态就绪（仅首次启动）
+        if not is_sender and create_if_not_exists:
+            logger.info(
+                f"监听器客户端 '{processed_queue_name}' 连接成功，延迟1秒启动消费（解决启动时序问题）")
+            await asyncio.sleep(1)
+
         return client
 
     @classmethod
@@ -508,6 +515,11 @@ class RabbitMQService:
             logger.info("服务关闭中，取消启动消费者")
             return
 
+        # 监听器启动消费前额外延迟1秒，确保consumer_tag完全生成（不删消息）
+        if cls._has_listeners and not client_name.startswith("sender-"):
+            logger.info(f"消费者 '{client_name}' 准备启动，延迟1秒等待消费状态就绪（不删除积压消息）")
+            await asyncio.sleep(1)
+
         # 创建停止事件
         stop_event = asyncio.Event()
         cls._consumer_events[client_name] = stop_event
@@ -522,6 +534,16 @@ class RabbitMQService:
 
                 while attempt < max_attempts and not stop_event.is_set() and not cls._is_shutdown:
                     try:
+                        # 启动消费前再次校验连接和队列状态
+                        if not await client.is_connected:
+                            logger.info(f"消费者 '{client_name}' 连接断开，尝试重连")
+                            await client.connect(force_reconnect=True, declare_queue=True)
+
+                        # 确保队列已就绪
+                        _, _, queue = await client._get_connection_resources()
+                        if not queue:
+                            raise Exception("队列未初始化完成")
+
                         consumer_tag = await client.start_consuming()
                         if consumer_tag:
                             break
@@ -541,7 +563,8 @@ class RabbitMQService:
 
                 # 记录消费者标签
                 cls._consumer_tags[client_name] = consumer_tag
-                logger.info(f"消费者 '{client_name}' 开始消费，tag: {consumer_tag}")
+                logger.info(
+                    f"消费者 '{client_name}' 开始消费，tag: {consumer_tag}（将处理队列中所有积压消息）")
 
                 # 等待停止事件
                 await stop_event.wait()
